% RELATCH_iAF1260_Example.m illustrates how RELATCH can be used to estimate
% the metabolic flux distribution and enzyme contributions in a reference
% state and to predict the metabolic flux distribution in a perturbed state
%
% Joonhoon Kim and Jennifer L. Reed 9/13/2012

%% Step 1: Estimate the flux distribution and enzyme contributions in a reference state
% Read iAF1260 metabolic model and experimental datasets
load RELATCH_iAF1260_Example.mat;
modelRef = model;
solutionRef = RELATCH_Reference(modelRef,Gene_Expression,External_Flux,MFA_Flux);

%% Step 2: Predict the flux distribution in a perturbed state

%% Example 1: Genetic perturbation (pgi (b4025) deletion)

% remove pgi gene from the model and allow the glucose uptake rate and ATP maintenance to change
modelPert = deleteModelGenes(modelRef,'b4025');
modelPert = changeRxnBounds(modelPert,{'EX_glc(e)','ATPM'},[-1000,0],'l');
% before adaptive laboratory evolution
alpha = 10; gamma = 1.1;
pgi_unevolved = RELATCH_Perturbed(modelPert,solutionRef,alpha,gamma);
% after adaptive laboratory evolution
alpha = 1; gamma = inf;
pgi_evolved = RELATCH_Perturbed(modelPert,solutionRef,alpha,gamma);

%% Example 2: Environmental perturbation (glucose aerobic to galactose aerobic)

% remove glucose from the media, add galactose to the media, and allow ATP maintenance to change
modelPert = changeRxnBounds(modelRef,{'EX_glc(e)','EX_gal(e)','ATPM'},[0,-1000,0],'l');
% before adaptation to environmental perturbation
alpha = 10; gamma = 1.1;
gal_unadapted = RELATCH_Perturbed(modelPert,solutionRef,alpha,gamma);
% before adaptation to environmental perturbation
alpha = 1; gamma = inf;
gal_adapted = RELATCH_Perturbed(modelPert,solutionRef,alpha,gamma);
